package net.gorry.eyefikey;

import java.util.Date;
import java.util.Iterator;
import java.util.TreeMap;
import java.util.concurrent.ExecutionException;

import android.net.Uri;
import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

public class ActivityMain extends Activity {
	private static final String TAG = "ActivityMain";
	private static final boolean V = false;
	private static final boolean D = false;
	private static final boolean I = true;//false;

	private Activity me;
	private eyefiKeyTask mEyefiKey;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		me = this;

		Button button = (Button)findViewById(R.id.getkey_button);
		button.setOnClickListener(onGetKeyButtonClick);
	}

	/**
	 * getkey_buttonのクリック処理
	 */
	private final Button.OnClickListener onGetKeyButtonClick = new Button.OnClickListener() {
		public void onClick(final View v) {
			if (I) Log.i(TAG, "onGetKeyButtonClick: onClick()");
			String username;
			String password;
			{
				EditText username_edit = (EditText)findViewById(R.id.username_edit);
				username = username_edit.getText().toString();
			}
			{
				EditText password_edit = (EditText)findViewById(R.id.password_edit);
				password = password_edit.getText().toString();
			}
			if (I) Log.i(TAG, "onGetKeyButtonClick: username=["+username+"], password=["+password+"]");

			mEyefiKey = new eyefiKeyTask(me);
			mEyefiKey.setUserName(username);
			mEyefiKey.setPassword(password);
			mEyefiKey.setHandler(onGetEyefiKey);
			mEyefiKey.execute(0);
		}
	};
	
	/**
	 * Uploadキー取得後のハンドラ
	 */
	private final Runnable onGetEyefiKey = new Runnable() {
		public void run() {
			int ret = 0;
			try {
				ret = (int)mEyefiKey.get();
			} catch (InterruptedException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (ExecutionException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			String msg = "";
			if (ret <= 0) {
				switch (ret) {
					default:
						msg = "[unknown error]";
						break;
					case 0:
						msg = "[no Device Information]";
						break;
					case -1:
						msg = "[can't connect server]";
						break;
					case -2:
						msg = "[can't decode server response]";
						break;
					case -3:
						msg = "[server return error on getting Access Token]";
						break;
					case -4:
						msg = "[can't get Access Token]";
						break;
					case -5:
						msg = "[can't get Device Information]";
						break;
					case -6:
						msg = "[server return error on getting Device Information]";
						break;
				}
			} else {
				for (int i=0; i<mEyefiKey.numDevice(); i++) {
					msg = msg + String.format("Device %d: %s: [%s/%s/%s] [%s]\nUploadKey = %s\n\n",
							i+1,
							mEyefiKey.deviceMac(i),
							mEyefiKey.deviceBrand(i),
							mEyefiKey.deviceName(i),
							mEyefiKey.deviceType(i),
							mEyefiKey.deviceId(i),
							mEyefiKey.deviceKey(i)
							);
				}
			}
			{
				EditText console_edit = (EditText)findViewById(R.id.console_edit);
				console_edit.setText(msg);
			}
		}
	};
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
	}

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        boolean ret = true;
        switch (item.getItemId()) {
        default:
            ret = super.onOptionsItemSelected(item);
            break;
        case R.id.menu_about:
        	showAbout();
            ret = true;
            break;
        }
        return ret;
    }

    public void showAbout() {
    	String versionName = null;
    	final PackageManager pm = getPackageManager();
    	try {
    		PackageInfo info = pm.getPackageInfo(me.getPackageName(), 0);
    		versionName = info.versionName;
    	} catch (final NameNotFoundException e) {
    		e.printStackTrace();
    	}
    	final AlertDialog.Builder bldr = new AlertDialog.Builder(me);
   		bldr.setTitle(me.getString(R.string.app_name));
    	bldr.setMessage("Version " + versionName + "\n" + me.getString(R.string.copyright));
    	bldr.setPositiveButton(R.string.contact_uri_text, onContactClick);
    	bldr.setIcon(R.drawable.ic_launcher);
    	bldr.create().show();

    }

	private final DialogInterface.OnClickListener onContactClick = new DialogInterface.OnClickListener() {
		public void onClick(DialogInterface dialog, int item) {
			if (I) Log.i(TAG, "onContactClick: onClick()");
			String url = me.getString(R.string.contact_uri);
			String url2 = url;
			final Intent intent = new Intent();
			intent.setAction(Intent.ACTION_VIEW);
			intent.setData(Uri.parse(url2));
			me.startActivity(intent);
		}
	};
	

}
